@@ -79,6 +79,10 @@ _LOAD_ERR = "Unable to load module: {err}"
 _GRP_METHODS = {'groups': 'add_argument_group',
                 'exclusive_groups': 'add_mutually_exclusive_group'}
 
+# Add builtin BooleanOptionalAction Action.
+# https://docs.python.org/3/library/argparse.html?highlight=argparse#action
+if sys.version_info >= (3, 9):
+    ACTIONS.update(BooleanOptionalAction=argparse.BooleanOptionalAction)
 
 #
 # Exceptions.
@@ -319,7 +323,7 @@ def _post_match(parser, parser_args, args_values, arg):
 def _exec_module(path, exec_conf, args_values):
     """Load and execute a function of a module according to **exec_conf**."""
     mdl_func = exec_conf.get('function', 'main')
-    mdl_tree = exec_conf['module']
+    mdl_tree = exec_conf['module'].replace('-', '_')
 
     try:
         mdl = importlib.import_module(mdl_tree)
@@ -801,7 +805,7 @@ def init(format='yaml', data=os.path.join(sys.path[0], 'cmd.yml'),
     elif format == 'raw':
         config = data
     else:
-        raise CLGError('unsupported format: %s' % format)
+        raise CLGError([], 'unsupported format: %s' % format)
     cmd = CommandLine(config, subcommands_keyword, deepcopy)
 
     # Activate completion if wished.
